////////////////////////////////////////////////////////////////////////
//
// Copyright (C) 2024-2026 The Octave Project Developers
//
// See the file COPYRIGHT.md in the top-level directory of this
// distribution or <https://octave.org/copyright/>.
//
// This file is part of Octave.
//
// Octave is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Octave is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Octave; see the file COPYING.  If not, see
// <https://www.gnu.org/licenses/>.
//
////////////////////////////////////////////////////////////////////////

#if ! defined (octave_separator_list_h)
#define octave_separator_list_h 1

#include "octave-config.h"

#include <list>

#include "token.h"

OCTAVE_BEGIN_NAMESPACE(octave)

class OCTINTERP_API separator_list : public std::list<token>
{
public:

  separator_list (const token& tok)
  {
    append (tok);
  }

  OCTAVE_DEFAULT_CONSTRUCT_COPY_MOVE_DELETE (separator_list)

  separator_list *append (const token& tok)
  {
    push_back (tok);

    return this;
  }

  int first_sep_char () const
  {
    token tok = front ();

    return tok.token_id ();
  }

  separator_list * dup () const
  {
    return new separator_list (*this);
  }
};

OCTAVE_END_NAMESPACE(octave)

#endif
